# coding: utf-8

"""
    videoapi

    The video APIs help you convert, encode, and transcode videos.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_video_api_client
from cloudmersive_video_api_client.api.video_api import VideoApi  # noqa: E501
from cloudmersive_video_api_client.rest import ApiException


class TestVideoApi(unittest.TestCase):
    """VideoApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_video_api_client.api.video_api.VideoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_video_convert_to_gif(self):
        """Test case for video_convert_to_gif

        Convert Video to Animated GIF format.  # noqa: E501
        """
        pass

    def test_video_convert_to_mov(self):
        """Test case for video_convert_to_mov

        Convert Video to MOV format.  # noqa: E501
        """
        pass

    def test_video_convert_to_mp4(self):
        """Test case for video_convert_to_mp4

        Convert Video to MP4 format.  # noqa: E501
        """
        pass

    def test_video_convert_to_webm(self):
        """Test case for video_convert_to_webm

        Convert Video to WEBM format.  # noqa: E501
        """
        pass

    def test_video_get_info(self):
        """Test case for video_get_info

        Get detailed information about a video or audio file  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
